@@ -73,7 +73,7 @@
 #else
 
 /* some compatibility layer */
-#if OPENSSL_VERSION_NUMBER < 0x1010000FL
+#if !HAVE_BIO_GET_DATA
 static inline void
 BIO_set_init(BIO *b, int init)
 {
@@ -101,6 +101,10 @@ BIO_get_data(const BIO *b)
 #define SSL_PTR BIO_get_data(bio)
 #endif
 
+#if !HAVE_ASN1_STRING_GET0_DATA
+#define ASN1_STRING_get0_data(x) ASN1_STRING_data(x)
+#endif
+
 static SSL_RET
 tds_pull_func_login(SSL_PULL_ARGS)
 {
@@ -590,7 +594,7 @@ tds_ssl_free(BIO *a)
 	return 1;
 }
 
-#if OPENSSL_VERSION_NUMBER < 0x1010000FL
+#if OPENSSL_VERSION_NUMBER < 0x1010000FL || defined(LIBRESSL_VERSION_NUMBER)
 static BIO_METHOD tds_method_login[1] = {
 {
 	BIO_TYPE_MEM,
@@ -654,7 +658,6 @@ tds_deinit_openssl_methods(void)
 #  endif
 #endif
 
-
 static SSL_CTX *
 tds_init_openssl(void)
 {
@@ -805,7 +808,7 @@ check_alt_names(X509 *cert, const char *hostname)
 		if (!name)
 			continue;
 
-		altptr = (const char *) ASN1_STRING_data(name->d.ia5);
+		altptr = (const char *) ASN1_STRING_get0_data(name->d.ia5);
 		altlen = (size_t) ASN1_STRING_length(name->d.ia5);
 
 		if (name->type == GEN_DNS && ip_size == 0) {
@@ -958,6 +961,7 @@ tds_ssl_init(TDSSOCKET *tds)
 		tls_msg = "checking hostname";
 		if (!cert || !check_hostname(cert, tds_dstr_cstr(&tds->login->server_host_name)))
 			goto cleanup;
+		X509_free(cert);
 	}
 
 	tdsdump_log(TDS_DBG_INFO1, "handshake succeeded!!\n");
